@@ -357,7 +357,7 @@ class model_training:
         
         """
 
-        self._split_tunning_data()
+        self._reduce_data()
         
 
         self.hyperparams = hyper_parameter_tunning(
@@ -539,44 +539,25 @@ class model_training:
             Dataset for hyperparameter tuning
         
         """
-        
-        tunning_data_size = int(self.data.shape[0] * self.params_prop)
-        
+
+
+        if self.X_train.empty:
+            self._split_data()
+
+
+        train_set = pd.concat([self.X_train, self.y_train], axis=1)
+
+        tunning_data_size = int(self.X_train.shape[0] * self.params_prop)
+
+        hyp_tune_data = self.data.sample(tunning_data_size)
+
         self.log.info('Hyper parameter tuning data set created')
-    
+
         self.log.info(f'Hyper parameter tuning data set:{tunning_data_size} rows')
-        
-        return self.data.sample(tunning_data_size)
 
+        self.X_train_param = hyp_tune_data[self.features]
 
-    def _split_tunning_data(self):
-        
-        """
-
-        Split data into training and test sets
-
-        Parameters
-        ----------
-        
-        None
-        
-        Returns
-        -------
-        
-        None
-        
-        """
-        
-        tunning_data = self._reduce_data()
-
-        self.X_train_param, self.X_test_param, self.y_train_param, self.y_test_param = split_data(data=tunning_data, target=self.target, test_size=self.test_size)
-        
-        self.log.info('Splitting hyperparameter tuning data into training and testing sets completed')
-        
-        self.log.info(f'Hyperparameter tuning training data set:{self.X_train_param.shape[0]} rows')
-        
-        self.log.info(f'Hyperparameter tuning testing data set:{self.X_test_param.shape[0]} rows')
-
+        self.y_train_param =  hyp_tune_data[self.target]
 
 
 # <<<<<<<<<<<<<<<<<<<<<<<<>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
@@ -1202,7 +1183,7 @@ def search_space_generator(classifier="xgboost"):
             'learning_rate': hp.choice('learning_rate', [0.0001, 0.001, 0.01, 0.1, 1.0]),
             'subsample': hp.choice('subsample', np.arange(0.1, 1.1, 0.1)),
             'colsample_bytree': hp.choice('colsample_bytree', np.arange(0.1, 1.1, 0.1)),
-            'gamma': hp.choice('gamma', np.arange(0.0, 1.0, 0.25)),
+            'gamma': hp.choice('gamma', np.arange(0.0, 5.0, 0.5)),
             'reg_lambda': hp.choice('reg_lambda', [1e-5, 1e-2, 0.1, 1, 10, 100]),
             'objective': 'binary:logistic',
             'booster': 'gbtree',
@@ -1213,28 +1194,30 @@ def search_space_generator(classifier="xgboost"):
             'n_jobs': -1,
         },
 
+    
+
+
         "random_forest" : {
             'n_estimators': hp.choice('n_estimators', range(100,1500,100)),
-            'max_depth': hp.choice('max_depth', range(2, 15, 1)),
-            'criterion': 'gini',
+            'max_depth': hp.choice('max_depth', range(2, 10, 1)),
             'min_samples_split': hp.choice('min_samples_split', [2, 5, 10]),
             'max_features' : hp.choice('max_features', ['auto', 'sqrt']),
             'bootstrap': True,
-            # 'importance_type': 'gain',
             'random_state': 801,
             'verbose' : 0,
             'n_jobs' : -1,
-            
         },
 
+
         "lightgbm" : {
-            'num_leaves' : hp.choice('num_leaves', range(20, 220, 20)),
-            'max_depth': hp.choice('max_depth', range(2, 15, 1)),
-            'learning_rate' : hp.choice('learning_rate', np.arange(0.01, 0.5, 0.01)),
+            'boosting_type' : hp.choice('boosting_type', ['gbdt', 'dart']),
+            'num_leaves' : hp.choice('num_leaves', range(20, 100, 10)),
+            'max_depth': hp.choice('max_depth', range(3, 13, 1)),
+            'learning_rate' : hp.choice('learning_rate', [0.0001, 0.001, 0.01, 0.1, 1.0]),
+            'min_child_samples' :  hp.choice('min_child_samples', range(5, 21,5)),
+            'min_split_gain' : hp.choice('min_split_gain', range(0, 15,2)),
             'n_estimators': hp.choice('n_estimators', range(100,1500,100)),
             'subsample' : hp.choice('subsample', np.arange(0.6, 1, 0.05)),
-            'min_child_samples' : hp.choice('min_child_samples', range(5,50,10)),
-            'boosting_type' : 'gbdt',
             'objective': 'binary',
             'importance_type': 'gain',
             'random_state': 801,
